LoginResult class
- Annotations
-
- @freezed
Constructors
-
LoginResult({required int uid, @JsonKey.new(name: 'is_system') required bool isSystem, @JsonKey.new(name: 'is_admin') required bool isAdmin, @JsonKey.new(name: 'user_context') required Map<
String, dynamic> userContext, required String db, @JsonKey.new(name: 'server_version') required String serverVersion, @JsonKey.new(name: 'server_version_info') required List serverVersionInfo, required String name, required String username, @JsonKey.new(name: 'partner_display_name') required String partnerDisplayName, @JsonKey.new(name: 'partner_id') required int partnerId, @JsonKey.new(name: 'web.base.url') required String webBaseUrl, @JsonKey.new(name: 'active_ids_limit') required int activeIdsLimit, @JsonKey.new(name: 'max_file_upload_size') required int maxFileUploadSize, @JsonKey.new(name: 'user_companies') required Map<String, dynamic> userCompanies, required Map<String, dynamic> currencies, @JsonKey.new(name: 'display_switch_company_menu') required bool displaySwitchCompanyMenu, @JsonKey.new(name: 'cache_hashes') required Map<String, dynamic> cacheHashes, @JsonKey.new(name: 'user_id') required List<int> userId, @JsonKey.new(name: 'web_tours') required List webTours, @JsonKey.new(name: 'notification_type') required String notificationType, @JsonKey.new(name: 'contigobot_initialized') required bool contigobotInitialized, @JsonKey.new(name: 'company_id') int? companyId}) -
constfactory
-
LoginResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
- activeIdsLimit → int
-
no setterinherited
-
cacheHashes
→ Map<
String, dynamic> -
no setterinherited
- companyId → int?
-
no setterinherited
- contigobotInitialized → bool
-
no setterinherited
-
copyWith
→ $LoginResultCopyWith<
LoginResult> -
no setterinherited
-
currencies
→ Map<
String, dynamic> -
no setterinherited
- db → String
-
no setterinherited
- displaySwitchCompanyMenu → bool
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAdmin → bool
-
no setterinherited
- isSystem → bool
-
no setterinherited
- maxFileUploadSize → int
-
no setterinherited
- name → String
-
no setterinherited
- notificationType → String
-
no setterinherited
- partnerDisplayName → String
-
no setterinherited
- partnerId → int
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverVersion → String
-
no setterinherited
- serverVersionInfo → List
-
no setterinherited
- uid → int
-
no setterinherited
-
userCompanies
→ Map<
String, dynamic> -
no setterinherited
-
userContext
→ Map<
String, dynamic> -
no setterinherited
-
userId
→ List<
int> -
no setterinherited
- username → String
-
no setterinherited
- webBaseUrl → String
-
no setterinherited
- webTours → List
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited